@@ -5,7 +5,7 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.167';
+our $VERSION = '1.168';
 
 use Quiq::FileHandle;
 
@@ -83,37 +83,16 @@ Inhalt. Dieser kann aus einer Datei oder einem String kommen.
 
 Programm:
 
-   1: require R1::HtmlTag;
-   2: require R1::Html::Listing;
-   3: 
-   4: my $h = R1::HtmlTag->new;
-   5: 
-   6: my $text = << '__PERL__';
-   7: #!/usr/bin/perl
-   8: 
-   9: =encoding utf8
-  10: 
-  11: Nur ein Demo-Programm.
-  12: 
-  13: =cut
-  14: 
-  15: print "Hello world!\n";
-  16: 
-  17: # eof
-  18: __PERL__
-  19: 
-  20: my $html = R1::Html::Listing->html($h,
-  21:     cssPrefix=>'sdoc-code',
-  22:     language=>'Perl',
-  23:     source=>\$text,
-  24: );
+  1: Command failed: Blob/sdoc_reference/sdoc-highlight perl pod
 
 Ergebnis:
 
-  1: 
+  1: Command failed: Blob/R1/Html/Listing/html-listing.pl html
 
 Im Browser:
 
+Command failed: Blob/R1/Html/Listing/html-listing.pl pod%%CLASS-CODE%%
+
 =head1 METHODS
 
 =head2 Konstruktor
@@ -400,7 +379,7 @@ sub html {
 
 =head1 VERSION
 
-1.167
+1.168
 
 =head1 AUTHOR
 
