@@ -5,10 +5,9 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.167';
+our $VERSION = '1.168';
 
 use Quiq::Path;
-use Quiq::Parameters;
 use Quiq::System;
 use Quiq::Progress;
 use Quiq::Hash;
@@ -228,7 +227,7 @@ sub runFetch {
     my $progressMeter = 1;
     my $progressNameSub = undef;
     
-    my $argA = Quiq::Parameters->extractToVariables(\@_,2,2,
+    my $argA = $class->parameters(2,2,\@_,
         -maxFetches => \$maxFetches,
         -maxProcesses => \$maxProcesses,
         -outputDir => \$outputDir,
@@ -358,7 +357,7 @@ sub runFetch {
 
 =head1 VERSION
 
-1.167
+1.168
 
 =head1 AUTHOR
 
