@@ -5,9 +5,8 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.167';
+our $VERSION = '1.168';
 
-use Quiq::Parameters;
 use Quiq::String;
 
 # -----------------------------------------------------------------------------
@@ -141,7 +140,7 @@ sub new {
 
     my $noTrailingZeros = 0;
 
-    my $argA = Quiq::Parameters->extractToVariables(\@_,0,1,
+    my $argA = $class->parameters(0,1,\@_,
         -noTrailingZeros => \$noTrailingZeros,
     );
     my $valueA = shift(@$argA) // [];
@@ -619,7 +618,7 @@ sub set {
 
 =head1 VERSION
 
-1.167
+1.168
 
 =head1 AUTHOR
 
